@@ -15,7 +15,7 @@ import requests
 from requests.exceptions import RequestException
 from requests_toolbelt.sessions import BaseUrlSession
 import sentry_sdk
-from sentry_sdk import capture_exception, configure_scope, push_scope
+from sentry_sdk import capture_exception, configure_scope, push_scope  # type: ignore
 from xdg import BaseDirectory
 
 __version__ = None
@@ -186,7 +186,7 @@ def cli(ctx, api_url, x_stumpf_token, offline, gitlab_url, gitlab_project_id):
     api = urlparse(api_url)
 
     if api.netloc == 'stumpf.avidannotations.com':
-        sentry_sdk.init(SENTRY_DSN)
+        sentry_sdk.init(SENTRY_DSN)  # type: ignore
 
     if not offline:
         try:
